@@ -262,7 +262,7 @@ def draw_board(fen="rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR",
         #im.save(open('tst.png','w'))
     
 if __name__ == '__main__':
-    print os.curdir()
+    print os.curdir
     print open('images/white_king.svg').read()
     parser = argparse.ArgumentParser(
         description='Create a chess board image from a fen description')
